You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@qpid.apache.org by kp...@apache.org on 2013/09/20 20:59:50 UTC

svn commit: r1525101 [21/21] - in /qpid/branches/linearstore/qpid: ./ bin/ cpp/ cpp/bindings/ cpp/bindings/qmf/ cpp/bindings/qmf/python/ cpp/bindings/qmf/ruby/ cpp/bindings/qmf/tests/ cpp/bindings/qmf2/ cpp/bindings/qmf2/examples/cpp/ cpp/bindings/qmf2...

Modified: qpid/branches/linearstore/qpid/java/systests/src/main/java/org/apache/qpid/server/store/SlowMessageStore.java
URL: http://svn.apache.org/viewvc/qpid/branches/linearstore/qpid/java/systests/src/main/java/org/apache/qpid/server/store/SlowMessageStore.java?rev=1525101&r1=1525100&r2=1525101&view=diff
==============================================================================
--- qpid/branches/linearstore/qpid/java/systests/src/main/java/org/apache/qpid/server/store/SlowMessageStore.java (original)
+++ qpid/branches/linearstore/qpid/java/systests/src/main/java/org/apache/qpid/server/store/SlowMessageStore.java Fri Sep 20 18:59:30 2013
@@ -40,19 +40,17 @@ public class SlowMessageStore implements
     private HashMap<String, Long> _preDelays = new HashMap<String, Long>();
     private HashMap<String, Long> _postDelays = new HashMap<String, Long>();
     private long _defaultDelay = 0L;
-    private MessageStore _realStore = new MemoryMessageStore();
-    private DurableConfigurationStore _durableConfigurationStore = (MemoryMessageStore) _realStore;
+    private MessageStore _realStore = new MessageStoreCreator().createMessageStore("Memory");
+    private DurableConfigurationStore _durableConfigurationStore = (DurableConfigurationStore) _realStore;
     private static final String PRE = "pre";
     private static final String POST = "post";
     private String DEFAULT_DELAY = "default";
 
     // ***** MessageStore Interface.
 
-    public void configureConfigStore(String name,
-                                     ConfigurationRecoveryHandler recoveryHandler,
-                                     VirtualHost virtualHost) throws Exception
+    public void configureConfigStore(VirtualHost virtualHost, ConfigurationRecoveryHandler recoveryHandler) throws Exception
     {
-        _logger.info("Starting SlowMessageStore on Virtualhost:" + name);
+        _logger.info("Starting SlowMessageStore on Virtualhost:" + virtualHost.getName());
 
         Object delaysAttr = virtualHost.getAttribute("slowMessageStoreDelays");
 
@@ -84,7 +82,7 @@ public class SlowMessageStore implements
                 _durableConfigurationStore = (DurableConfigurationStore)o;
             }
         }
-        _durableConfigurationStore.configureConfigStore(name, recoveryHandler, virtualHost);
+        _durableConfigurationStore.configureConfigStore(virtualHost, recoveryHandler);
 
     }
 
@@ -153,11 +151,10 @@ public class SlowMessageStore implements
     }
 
 
-    public void configureMessageStore(String name,
-                                      MessageStoreRecoveryHandler messageRecoveryHandler,
+    public void configureMessageStore(VirtualHost virtualHost, MessageStoreRecoveryHandler messageRecoveryHandler,
                                       TransactionLogRecoveryHandler tlogRecoveryHandler) throws Exception
     {
-        _realStore.configureMessageStore(name, messageRecoveryHandler, tlogRecoveryHandler);
+        _realStore.configureMessageStore(virtualHost, messageRecoveryHandler, tlogRecoveryHandler);
     }
 
     public void close() throws Exception
@@ -190,6 +187,15 @@ public class SlowMessageStore implements
     }
 
     @Override
+    public UUID[] removeConfiguredObjects(final UUID... objects) throws AMQStoreException
+    {
+        doPreDelay("remove");
+        UUID[] removed = _durableConfigurationStore.removeConfiguredObjects(objects);
+        doPostDelay("remove");
+        return removed;
+    }
+
+    @Override
     public void update(UUID id, String type, Map<String, Object> attributes) throws AMQStoreException
     {
         doPreDelay("update");
@@ -197,6 +203,22 @@ public class SlowMessageStore implements
         doPostDelay("update");
     }
 
+    @Override
+    public void update(ConfiguredObjectRecord... records) throws AMQStoreException
+    {
+        doPreDelay("update");
+        _durableConfigurationStore.update(records);
+        doPostDelay("update");
+    }
+
+    @Override
+    public void update(boolean createIfNecessary, ConfiguredObjectRecord... records) throws AMQStoreException
+    {
+        doPreDelay("update");
+        _durableConfigurationStore.update(createIfNecessary, records);
+        doPostDelay("update");
+    }
+
     public Transaction newTransaction()
     {
         doPreDelay("beginTran");

Modified: qpid/branches/linearstore/qpid/java/systests/src/main/java/org/apache/qpid/systest/management/jmx/ExchangeManagementTest.java
URL: http://svn.apache.org/viewvc/qpid/branches/linearstore/qpid/java/systests/src/main/java/org/apache/qpid/systest/management/jmx/ExchangeManagementTest.java?rev=1525101&r1=1525100&r2=1525101&view=diff
==============================================================================
--- qpid/branches/linearstore/qpid/java/systests/src/main/java/org/apache/qpid/systest/management/jmx/ExchangeManagementTest.java (original)
+++ qpid/branches/linearstore/qpid/java/systests/src/main/java/org/apache/qpid/systest/management/jmx/ExchangeManagementTest.java Fri Sep 20 18:59:30 2013
@@ -53,10 +53,10 @@ public class ExchangeManagementTest exte
         _managedBroker = _jmxUtils.getManagedBroker(VIRTUAL_HOST);
         _testQueueName = getTestName();
         _managedBroker.createNewQueue(_testQueueName, null, true);
-        _directExchange = _jmxUtils.getManagedExchange(ExchangeDefaults.DIRECT_EXCHANGE_NAME.asString());
-        _topicExchange = _jmxUtils.getManagedExchange(ExchangeDefaults.TOPIC_EXCHANGE_NAME.asString());
-        _fanoutExchange = _jmxUtils.getManagedExchange(ExchangeDefaults.FANOUT_EXCHANGE_NAME.asString());
-        _headersExchange = _jmxUtils.getManagedExchange(ExchangeDefaults.HEADERS_EXCHANGE_NAME.asString());
+        _directExchange = _jmxUtils.getManagedExchange(ExchangeDefaults.DIRECT_EXCHANGE_NAME);
+        _topicExchange = _jmxUtils.getManagedExchange(ExchangeDefaults.TOPIC_EXCHANGE_NAME);
+        _fanoutExchange = _jmxUtils.getManagedExchange(ExchangeDefaults.FANOUT_EXCHANGE_NAME);
+        _headersExchange = _jmxUtils.getManagedExchange(ExchangeDefaults.HEADERS_EXCHANGE_NAME);
 
         _connection = getConnection();
         _connection.start();

Modified: qpid/branches/linearstore/qpid/java/systests/src/main/java/org/apache/qpid/systest/management/jmx/ManagementLoggingTest.java
URL: http://svn.apache.org/viewvc/qpid/branches/linearstore/qpid/java/systests/src/main/java/org/apache/qpid/systest/management/jmx/ManagementLoggingTest.java?rev=1525101&r1=1525100&r2=1525101&view=diff
==============================================================================
--- qpid/branches/linearstore/qpid/java/systests/src/main/java/org/apache/qpid/systest/management/jmx/ManagementLoggingTest.java (original)
+++ qpid/branches/linearstore/qpid/java/systests/src/main/java/org/apache/qpid/systest/management/jmx/ManagementLoggingTest.java Fri Sep 20 18:59:30 2013
@@ -249,7 +249,7 @@ public class ManagementLoggingTest exten
 
             // Validate the keystore path is as expected
             assertTrue("SSL Keystore entry expected.:" + getMessageString(log),
-                       getMessageString(log).endsWith(TestSSLConstants.BROKER_KEYSTORE));
+                       getMessageString(log).endsWith("systestsKeyStore"));
         }
     }
 

Modified: qpid/branches/linearstore/qpid/java/systests/src/main/java/org/apache/qpid/systest/management/jmx/QueueManagementTest.java
URL: http://svn.apache.org/viewvc/qpid/branches/linearstore/qpid/java/systests/src/main/java/org/apache/qpid/systest/management/jmx/QueueManagementTest.java?rev=1525101&r1=1525100&r2=1525101&view=diff
==============================================================================
--- qpid/branches/linearstore/qpid/java/systests/src/main/java/org/apache/qpid/systest/rest/Asserts.java (original)
+++ qpid/branches/linearstore/qpid/java/systests/src/main/java/org/apache/qpid/systest/rest/Asserts.java Fri Sep 20 18:59:30 2013
@@ -51,7 +51,7 @@ public class Asserts
         assertNotNull("Virtualhost " + virtualHostName + " data are not found", virtualHost);
         assertAttributesPresent(virtualHost, VirtualHost.AVAILABLE_ATTRIBUTES, VirtualHost.TIME_TO_LIVE,
                 VirtualHost.CREATED, VirtualHost.UPDATED, VirtualHost.SUPPORTED_QUEUE_TYPES, VirtualHost.STORE_PATH,
-                VirtualHost.CONFIG_PATH, VirtualHost.TYPE);
+                VirtualHost.CONFIG_PATH, VirtualHost.TYPE, VirtualHost.CONFIG_STORE_PATH, VirtualHost.CONFIG_STORE_TYPE);
 
         assertEquals("Unexpected value of attribute " + VirtualHost.NAME, virtualHostName, virtualHost.get(VirtualHost.NAME));
         assertNotNull("Unexpected value of attribute " + VirtualHost.ID, virtualHost.get(VirtualHost.ID));

Modified: qpid/branches/linearstore/qpid/java/systests/src/main/java/org/apache/qpid/systest/rest/LogRecordsRestTest.java
URL: http://svn.apache.org/viewvc/qpid/branches/linearstore/qpid/java/systests/src/main/java/org/apache/qpid/systest/rest/LogRecordsRestTest.java?rev=1525101&r1=1525100&r2=1525101&view=diff
==============================================================================
--- qpid/branches/linearstore/qpid/java/systests/src/main/java/org/apache/qpid/systest/rest/LogRecordsRestTest.java (original)
+++ qpid/branches/linearstore/qpid/java/systests/src/main/java/org/apache/qpid/systest/rest/LogRecordsRestTest.java Fri Sep 20 18:59:30 2013
@@ -39,4 +39,25 @@ public class LogRecordsRestTest extends 
         assertEquals("Unexpected thread", "main", record.get("thread"));
         assertEquals("Unexpected logger", "qpid.message.broker.ready", record.get("logger"));
     }
+
+    public void testGetLogsFromGivenId() throws Exception
+    {
+        List<Map<String, Object>> logs = getRestTestHelper().getJsonAsList("/rest/logrecords");
+        assertNotNull("Logs data cannot be null", logs);
+        assertTrue("Logs are not found", logs.size() > 0);
+
+        Map<String, Object> lastLog = logs.get(logs.size() -1);
+        Object lastId = lastLog.get("id");
+
+        //make sure that new logs are created
+        getConnection();
+
+        List<Map<String, Object>> newLogs = getRestTestHelper().getJsonAsList("/rest/logrecords?lastLogId=" + lastId);
+        assertNotNull("Logs data cannot be null", newLogs);
+        assertTrue("Logs are not found", newLogs.size() > 0);
+
+        Object nextId = newLogs.get(0).get("id");
+
+        assertEquals("Unexpected next log id", ((Number)lastId).longValue() + 1, ((Number)nextId).longValue());
+    }
 }

Modified: qpid/branches/linearstore/qpid/java/systests/src/main/java/org/apache/qpid/systest/rest/MessagesRestTest.java
URL: http://svn.apache.org/viewvc/qpid/branches/linearstore/qpid/java/systests/src/main/java/org/apache/qpid/systest/rest/MessagesRestTest.java?rev=1525101&r1=1525100&r2=1525101&view=diff
==============================================================================
--- qpid/branches/linearstore/qpid/java/systests/src/main/java/org/apache/qpid/systest/rest/MessagesRestTest.java (original)
+++ qpid/branches/linearstore/qpid/java/systests/src/main/java/org/apache/qpid/systest/rest/MessagesRestTest.java Fri Sep 20 18:59:30 2013
@@ -62,7 +62,7 @@ public class MessagesRestTest extends Qp
         _session = _connection.createSession(true, Session.SESSION_TRANSACTED);
         String queueName = getTestQueueName();
         Destination queue = _session.createQueue(queueName);
-        _session.createConsumer(queue);
+        _session.createConsumer(queue).close();
         _producer = _session.createProducer(queue);
 
         _ttl = TimeUnit.DAYS.toMillis(1);
@@ -318,7 +318,7 @@ public class MessagesRestTest extends Qp
     {
         if (even)
         {
-            assertEquals("Unexpected message attribute expirationTime", 0, message.get("expirationTime"));
+            assertNull("Unexpected message attribute expirationTime", message.get("expirationTime"));
             assertEquals("Unexpected message attribute priority", 4, message.get("priority"));
             assertEquals("Unexpected message attribute persistent", Boolean.TRUE, message.get("persistent"));
         }
@@ -348,7 +348,6 @@ public class MessagesRestTest extends Qp
         assertNotNull("Unexpected message attribute mimeType", message.get("mimeType"));
         assertNotNull("Unexpected message attribute userId", message.get("userId"));
         assertNotNull("Message priority cannot be null", message.get("priority"));
-        assertNotNull("Message expirationTime cannot be null", message.get("expirationTime"));
         assertNotNull("Message persistent cannot be null", message.get("persistent"));
     }
 }

Modified: qpid/branches/linearstore/qpid/java/systests/src/main/java/org/apache/qpid/systest/rest/RestTestHelper.java
URL: http://svn.apache.org/viewvc/qpid/branches/linearstore/qpid/java/systests/src/main/java/org/apache/qpid/systest/rest/RestTestHelper.java?rev=1525101&r1=1525100&r2=1525101&view=diff
==============================================================================
--- qpid/branches/linearstore/qpid/java/systests/src/main/java/org/apache/qpid/systest/rest/RestTestHelper.java (original)
+++ qpid/branches/linearstore/qpid/java/systests/src/main/java/org/apache/qpid/systest/rest/RestTestHelper.java Fri Sep 20 18:59:30 2013
@@ -468,4 +468,11 @@ public class RestTestHelper
         connection.disconnect();
         return responseCode;
     }
+
+    public byte[] getBytes(String path) throws IOException
+    {
+        HttpURLConnection connection = openManagementConnection(path, "GET");
+        connection.connect();
+        return readConnectionInputStream(connection);
+    }
 }

Modified: qpid/branches/linearstore/qpid/java/systests/src/main/java/org/apache/qpid/systest/rest/StructureRestTest.java
URL: http://svn.apache.org/viewvc/qpid/branches/linearstore/qpid/java/systests/src/main/java/org/apache/qpid/systest/rest/StructureRestTest.java?rev=1525101&r1=1525100&r2=1525101&view=diff
==============================================================================
--- qpid/branches/linearstore/qpid/java/systests/src/main/java/org/apache/qpid/systest/rest/StructureRestTest.java (original)
+++ qpid/branches/linearstore/qpid/java/systests/src/main/java/org/apache/qpid/systest/rest/StructureRestTest.java Fri Sep 20 18:59:30 2013
@@ -80,8 +80,8 @@ public class StructureRestTest extends Q
                 Map<String, Object> exchange = getRestTestHelper().find("name", exchangeName, exchanges);
                 assertNotNull("Exchange " + exchangeName + " is not found ", exchange);
                 assertNode(exchange, exchangeName);
-                if (ExchangeDefaults.DIRECT_EXCHANGE_NAME.asString().equalsIgnoreCase(exchangeName) ||
-                    ExchangeDefaults.DEFAULT_EXCHANGE_NAME.asString().equalsIgnoreCase(exchangeName))
+                if (ExchangeDefaults.DIRECT_EXCHANGE_NAME.equalsIgnoreCase(exchangeName) ||
+                    ExchangeDefaults.DEFAULT_EXCHANGE_NAME.equalsIgnoreCase(exchangeName))
                 {
                     @SuppressWarnings("unchecked")
                     List<Map<String, Object>> bindings = (List<Map<String, Object>>) exchange.get("bindings");

Modified: qpid/branches/linearstore/qpid/java/systests/src/main/java/org/apache/qpid/systest/rest/VirtualHostRestTest.java
URL: http://svn.apache.org/viewvc/qpid/branches/linearstore/qpid/java/systests/src/main/java/org/apache/qpid/systest/rest/VirtualHostRestTest.java?rev=1525101&r1=1525100&r2=1525101&view=diff
==============================================================================
--- qpid/branches/linearstore/qpid/java/systests/src/main/java/org/apache/qpid/systest/rest/VirtualHostRestTest.java (original)
+++ qpid/branches/linearstore/qpid/java/systests/src/main/java/org/apache/qpid/systest/rest/VirtualHostRestTest.java Fri Sep 20 18:59:30 2013
@@ -37,6 +37,7 @@ import org.apache.qpid.server.model.Exch
 import org.apache.qpid.server.model.Queue;
 import org.apache.qpid.server.model.VirtualHost;
 import org.apache.qpid.server.queue.AMQQueueFactory;
+import org.apache.qpid.server.queue.QueueArgumentsConverter;
 import org.apache.qpid.server.virtualhost.StandardVirtualHostFactory;
 import org.apache.qpid.test.utils.TestFileUtils;
 import org.apache.qpid.util.FileUtils;
@@ -291,7 +292,7 @@ public class VirtualHostRestTest extends
 
         Asserts.assertQueue(queueName , "lvq", lvqQueue);
         assertEquals("Unexpected value of queue attribute " + Queue.DURABLE, Boolean.TRUE, lvqQueue.get(Queue.DURABLE));
-        assertEquals("Unexpected lvq key attribute", AMQQueueFactory.QPID_LVQ_KEY, lvqQueue.get(Queue.LVQ_KEY));
+        assertEquals("Unexpected lvq key attribute", AMQQueueFactory.QPID_DEFAULT_LVQ_KEY, lvqQueue.get(Queue.LVQ_KEY));
     }
 
     public void testPutCreateSortedQueueWithoutKey() throws Exception
@@ -460,7 +461,7 @@ public class VirtualHostRestTest extends
         String queueName = getTestQueueName();
 
         Map<String, Object> attributes = new HashMap<String, Object>();
-        attributes.put(AMQQueueFactory.X_QPID_DLQ_ENABLED, true);
+        attributes.put(Queue.CREATE_DLQ_ON_CREATION, true);
 
         //verify the starting state
         Map<String, Object> hostDetails = getRestTestHelper().getJsonAsSingletonList("/rest/virtualhost/test");

Modified: qpid/branches/linearstore/qpid/java/systests/src/main/java/org/apache/qpid/test/client/destination/AddressBasedDestinationTest.java
URL: http://svn.apache.org/viewvc/qpid/branches/linearstore/qpid/java/systests/src/main/java/org/apache/qpid/test/client/destination/AddressBasedDestinationTest.java?rev=1525101&r1=1525100&r2=1525101&view=diff
==============================================================================
--- qpid/branches/linearstore/qpid/java/systests/src/main/java/org/apache/qpid/test/client/destination/AddressBasedDestinationTest.java (original)
+++ qpid/branches/linearstore/qpid/java/systests/src/main/java/org/apache/qpid/test/client/destination/AddressBasedDestinationTest.java Fri Sep 20 18:59:30 2013
@@ -200,8 +200,8 @@ public class AddressBasedDestinationTest
                                  "{" +
                                      "exclusive: true," +
                                      "arguments: {" +
-                                        "'qpid.max_size': 1000," +
-                                        "'qpid.max_count': 100" +
+                                        "'qpid.alert_size': 1000," +
+                                        "'qpid.alert_count': 100" +
                                      "}" +
                                   "}, " +
                                   "x-bindings: [{exchange : 'amq.direct', key : test}, " +
@@ -401,7 +401,7 @@ public class AddressBasedDestinationTest
                                "x-declare: " +
                                "{ " +
                                      "auto-delete: true," +
-                                     "arguments: {'qpid.max_count': 100}" +
+                                     "arguments: {'qpid.alert_count': 100}" +
                                "}, " +
                                "x-bindings: [{exchange : 'amq.direct', key : test}, " +
                                             "{exchange : 'amq.topic', key : 'a.#'}," +
@@ -485,7 +485,7 @@ public class AddressBasedDestinationTest
     {
         Hashtable<String,String> map = new Hashtable<String,String>();
         map.put("destination.myQueue1", "ADDR:my-queue/hello; {create: always, node: " +
-                "{x-declare: {auto-delete: true, arguments : {'qpid.max_size': 1000}}}}");
+                "{x-declare: {auto-delete: true, arguments : {'qpid.alert_size': 1000}}}}");
 
         map.put("destination.myQueue2", "ADDR:my-queue2; { create: receiver }");
 
@@ -603,7 +603,7 @@ public class AddressBasedDestinationTest
         String addr = "ADDR:amq.direct/x512; {" +
         "link : {name : 'MY.RESP.QUEUE', " +
         "x-declare : { auto-delete: true, exclusive: true, " +
-                     "arguments : {'qpid.max_size': 1000, 'qpid.policy_type': ring} } } }";
+                     "arguments : {'qpid.alert_size': 1000, 'qpid.policy_type': ring} } } }";
         queue = ssn.createQueue(addr);
 
         cons = ssn.createConsumer(queue);
@@ -1403,7 +1403,7 @@ public class AddressBasedDestinationTest
         Session ssn = _connection.createSession(false,Session.AUTO_ACKNOWLEDGE);
         String xDeclareArgs = "x-declare: { exclusive: false, auto-delete: false," +
                                            "alternate-exchange: 'amq.fanout'," +
-                                           "arguments: {'qpid.max_size': 1000,'qpid.max_count': 100}" +
+                                           "arguments: {'qpid.alert_size': 1000,'qpid.alert_count': 100}" +
                                           "}";
 
         String addr = "ADDR:amq.topic/test; {link: {name:my-queue, durable:true," + xDeclareArgs + "}}";

Modified: qpid/branches/linearstore/qpid/java/systests/src/main/java/org/apache/qpid/test/unit/basic/MultipleConnectionTest.java
URL: http://svn.apache.org/viewvc/qpid/branches/linearstore/qpid/java/systests/src/main/java/org/apache/qpid/test/unit/basic/MultipleConnectionTest.java?rev=1525101&r1=1525100&r2=1525101&view=diff
==============================================================================
--- qpid/branches/linearstore/qpid/java/systests/src/main/java/org/apache/qpid/test/unit/basic/MultipleConnectionTest.java (original)
+++ qpid/branches/linearstore/qpid/java/systests/src/main/java/org/apache/qpid/test/unit/basic/MultipleConnectionTest.java Fri Sep 20 18:59:30 2013
@@ -19,6 +19,7 @@
  */
 package org.apache.qpid.test.unit.basic;
 
+import org.apache.qpid.framing.AMQShortString;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -190,7 +191,7 @@ public class MultipleConnectionTest exte
         String broker = _connectionString;
         int messages = 10;
 
-        AMQTopic topic = new AMQTopic(ExchangeDefaults.TOPIC_EXCHANGE_NAME, "amq.topic");
+        AMQTopic topic = new AMQTopic(AMQShortString.valueOf(ExchangeDefaults.TOPIC_EXCHANGE_NAME), "amq.topic");
 
         Receiver[] receivers = new Receiver[] { new Receiver(broker, topic, 2), new Receiver(broker, topic, 14) };
 

Modified: qpid/branches/linearstore/qpid/java/systests/src/main/java/org/apache/qpid/test/unit/client/connection/ConnectionTest.java
URL: http://svn.apache.org/viewvc/qpid/branches/linearstore/qpid/java/systests/src/main/java/org/apache/qpid/test/unit/client/connection/ConnectionTest.java?rev=1525101&r1=1525100&r2=1525101&view=diff
==============================================================================
--- qpid/branches/linearstore/qpid/java/systests/src/main/java/org/apache/qpid/test/unit/client/connection/ConnectionTest.java (original)
+++ qpid/branches/linearstore/qpid/java/systests/src/main/java/org/apache/qpid/test/unit/client/connection/ConnectionTest.java Fri Sep 20 18:59:30 2013
@@ -88,16 +88,16 @@ public class ConnectionTest extends Qpid
             AMQSession sess = (AMQSession) conn.createSession(false, Session.AUTO_ACKNOWLEDGE);
 
             sess.declareExchange(new AMQShortString("test.direct"),
-                    ExchangeDefaults.DIRECT_EXCHANGE_CLASS, false);
+                    AMQShortString.valueOf(ExchangeDefaults.DIRECT_EXCHANGE_CLASS), false);
 
             sess.declareExchange(new AMQShortString("tmp.direct"),
-                    ExchangeDefaults.DIRECT_EXCHANGE_CLASS, false);
+                    AMQShortString.valueOf(ExchangeDefaults.DIRECT_EXCHANGE_CLASS), false);
 
             sess.declareExchange(new AMQShortString("tmp.topic"),
-                    ExchangeDefaults.TOPIC_EXCHANGE_CLASS, false);
+                    AMQShortString.valueOf(ExchangeDefaults.TOPIC_EXCHANGE_CLASS), false);
 
             sess.declareExchange(new AMQShortString("test.topic"),
-                    ExchangeDefaults.TOPIC_EXCHANGE_CLASS, false);
+                    AMQShortString.valueOf(ExchangeDefaults.TOPIC_EXCHANGE_CLASS), false);
 
             QueueSession queueSession = conn.createQueueSession(false, Session.AUTO_ACKNOWLEDGE);
 

Modified: qpid/branches/linearstore/qpid/java/systests/src/main/java/org/apache/qpid/test/utils/QpidBrokerTestCase.java
URL: http://svn.apache.org/viewvc/qpid/branches/linearstore/qpid/java/systests/src/main/java/org/apache/qpid/test/utils/QpidBrokerTestCase.java?rev=1525101&r1=1525100&r2=1525101&view=diff
==============================================================================
--- qpid/branches/linearstore/qpid/java/systests/src/main/java/org/apache/qpid/test/utils/QpidBrokerTestCase.java (original)
+++ qpid/branches/linearstore/qpid/java/systests/src/main/java/org/apache/qpid/test/utils/QpidBrokerTestCase.java Fri Sep 20 18:59:30 2013
@@ -57,6 +57,7 @@ import org.apache.qpid.client.AMQConnect
 import org.apache.qpid.client.AMQQueue;
 import org.apache.qpid.client.AMQTopic;
 import org.apache.qpid.exchange.ExchangeDefaults;
+import org.apache.qpid.framing.AMQShortString;
 import org.apache.qpid.jms.BrokerDetails;
 import org.apache.qpid.jms.ConnectionURL;
 import org.apache.qpid.server.Broker;
@@ -66,7 +67,6 @@ import org.apache.qpid.server.model.Port
 import org.apache.qpid.server.model.VirtualHost;
 import org.apache.qpid.server.plugin.MessageStoreFactory;
 import org.apache.qpid.server.protocol.AmqpProtocolVersion;
-import org.apache.qpid.server.store.MemoryMessageStore;
 import org.apache.qpid.server.store.MessageStoreConstants;
 import org.apache.qpid.server.store.MessageStoreCreator;
 import org.apache.qpid.url.URLSyntaxException;
@@ -250,20 +250,12 @@ public class QpidBrokerTestCase extends 
 
     private void initialiseLogConfigFile()
     {
-        try
-        {
-            _logger.info("About to initialise log config file from system property: " + LOG4J_CONFIG_FILE_PATH);
+        _logger.info("About to initialise log config file from system property: " + LOG4J_CONFIG_FILE_PATH);
 
-            URI uri = new URI("file", LOG4J_CONFIG_FILE_PATH, null);
-            _logConfigFile = new File(uri);
-            if(!_logConfigFile.exists())
-            {
-                throw new RuntimeException("Log config file " + _logConfigFile.getAbsolutePath() + " does not exist");
-            }
-        }
-        catch (URISyntaxException e)
+        _logConfigFile = new File(LOG4J_CONFIG_FILE_PATH);
+        if(!_logConfigFile.exists())
         {
-            throw new RuntimeException("Couldn't create URI from log4.configuration: " + LOG4J_CONFIG_FILE_PATH, e);
+            throw new RuntimeException("Log config file " + _logConfigFile.getAbsolutePath() + " does not exist");
         }
     }
 
@@ -634,17 +626,17 @@ public class QpidBrokerTestCase extends 
 
     public String getTestConfigFile(int port)
     {
-        return _output + "/" + getTestQueueName() + "-" + port + "-config";
+        return _output + File.separator + getTestQueueName() + "-" + port + "-config";
     }
 
     public String getTestVirtualhostsFile(int port)
     {
-        return _output + "/" + getTestQueueName() + "-" + port + "-virtualhosts.xml";
+        return _output + File.separator + getTestQueueName() + "-" + port + "-virtualhosts.xml";
     }
 
     private String relativeToQpidHome(String file)
     {
-        return file.replace(System.getProperty(QPID_HOME,"QPID_HOME") + "/","");
+        return file.replace(System.getProperty(QPID_HOME,"QPID_HOME") + File.separator,"");
     }
 
     protected String getPathRelativeToWorkingDirectory(String file)
@@ -1199,7 +1191,7 @@ public class QpidBrokerTestCase extends 
      */
     public Topic getTestTopic()
     {
-        return new AMQTopic(ExchangeDefaults.TOPIC_EXCHANGE_NAME, getTestQueueName());
+        return new AMQTopic(AMQShortString.valueOf(ExchangeDefaults.TOPIC_EXCHANGE_NAME), getTestQueueName());
     }
 
     @Override
@@ -1433,10 +1425,10 @@ public class QpidBrokerTestCase extends 
     public String getTestProfileMessageStoreType()
     {
         final String storeClass = getTestProfileMessageStoreClassName();
-        if (storeClass == null)
+       /* if (storeClass == null)
         {
-            return MemoryMessageStore.TYPE;
-        }
+            return "Memory";
+        }*/
         return supportedStoresClassToTypeMapping.get(storeClass);
     }
 

Propchange: qpid/branches/linearstore/qpid/java/systests/src/main/java/org/apache/qpid/test/utils/QpidBrokerTestCase.java
------------------------------------------------------------------------------
  Merged /qpid/trunk/qpid/java/systests/src/main/java/org/apache/qpid/test/utils/QpidBrokerTestCase.java:r1501885-1525056

Modified: qpid/branches/linearstore/qpid/java/systests/src/main/java/org/apache/qpid/test/utils/TestBrokerConfiguration.java
URL: http://svn.apache.org/viewvc/qpid/branches/linearstore/qpid/java/systests/src/main/java/org/apache/qpid/test/utils/TestBrokerConfiguration.java?rev=1525101&r1=1525100&r2=1525101&view=diff
==============================================================================
--- qpid/branches/linearstore/qpid/java/systests/src/main/java/org/apache/qpid/test/utils/TestBrokerConfiguration.java (original)
+++ qpid/branches/linearstore/qpid/java/systests/src/main/java/org/apache/qpid/test/utils/TestBrokerConfiguration.java Fri Sep 20 18:59:30 2013
@@ -38,6 +38,7 @@ import org.apache.qpid.server.model.Grou
 import org.apache.qpid.server.model.KeyStore;
 import org.apache.qpid.server.model.Plugin;
 import org.apache.qpid.server.model.Port;
+import org.apache.qpid.server.model.PreferencesProvider;
 import org.apache.qpid.server.model.TrustStore;
 import org.apache.qpid.server.model.UUIDGenerator;
 import org.apache.qpid.server.model.VirtualHost;
@@ -295,4 +296,16 @@ public class TestBrokerConfiguration
         _saved = saved;
     }
 
+    public void addPreferencesProviderConfiguration(String authenticationProvider, Map<String, Object> attributes)
+    {
+        ConfigurationEntry pp = new ConfigurationEntry(UUIDGenerator.generateRandomUUID(),
+                PreferencesProvider.class.getSimpleName(), attributes, Collections.<UUID> emptySet(), _store);
+        ConfigurationEntry ap = findObjectByName(authenticationProvider);
+        Set<UUID> children = new HashSet<UUID>();
+        children.addAll(ap.getChildrenIds());
+        children.add(pp.getId());
+        ConfigurationEntry newAp = new ConfigurationEntry(ap.getId(), ap.getType(), ap.getAttributes(), children, _store);
+        _store.save(newAp, pp);
+    }
+
 }

Propchange: qpid/branches/linearstore/qpid/java/test-profiles/
------------------------------------------------------------------------------
  Merged /qpid/trunk/qpid/java/test-profiles:r1501885-1525056

Modified: qpid/branches/linearstore/qpid/java/test-profiles/CPPExcludes
URL: http://svn.apache.org/viewvc/qpid/branches/linearstore/qpid/java/test-profiles/CPPExcludes?rev=1525101&r1=1525100&r2=1525101&view=diff
==============================================================================
--- qpid/branches/linearstore/qpid/java/test-profiles/CPPExcludes (original)
+++ qpid/branches/linearstore/qpid/java/test-profiles/CPPExcludes Fri Sep 20 18:59:30 2013
@@ -62,6 +62,7 @@ org.apache.qpid.test.client.timeouts.Syn
 // c++ broker doesn't support message bouncing
 org.apache.qpid.server.exchange.ReturnUnroutableMandatoryMessageTest#*
 org.apache.qpid.test.unit.topic.DurableSubscriptionTest#testUnsubscribeWhenUsingSelectorMakesTopicUnreachable
+org.apache.qpid.test.unit.client.connection.ExceptionListenerTest#testExceptionListenerConnectionStopDeadlock
 
 // c++ broker expires messages on delivery or when the queue cleaner thread runs.
 org.apache.qpid.server.queue.TimeToLiveTest#testActiveTTL
@@ -187,3 +188,5 @@ org.apache.qpid.client.ssl.SSLTest#testC
 // QPID-2796 : Java 0-10 client only sends heartbeats in response to heartbeats from the server, not timeout based
 org.apache.qpid.client.HeartbeatTest#testReadOnlyConnectionHeartbeats
 
+// Exclude java broker specific behavior allowing queue re-bind to topic exchanges on 0.8/0-10 paths
+org.apache.qpid.server.queue.QueueBindTest#testQueueCanBeReboundOnTopicExchange

Propchange: qpid/branches/linearstore/qpid/java/test-profiles/CPPExcludes
------------------------------------------------------------------------------
  Merged /qpid/trunk/qpid/java/test-profiles/CPPExcludes:r1501885-1525056

Modified: qpid/branches/linearstore/qpid/java/test-profiles/Java010Excludes
URL: http://svn.apache.org/viewvc/qpid/branches/linearstore/qpid/java/test-profiles/Java010Excludes?rev=1525101&r1=1525100&r2=1525101&view=diff
==============================================================================
--- qpid/branches/linearstore/qpid/java/test-profiles/Java010Excludes (original)
+++ qpid/branches/linearstore/qpid/java/test-profiles/Java010Excludes Fri Sep 20 18:59:30 2013
@@ -20,6 +20,7 @@
 // Those tests are testing 0.8..-0-9-1 specific semantics
 org.apache.qpid.test.client.ImmediateAndMandatoryPublishingTest#*
 org.apache.qpid.test.client.CloseOnNoRouteForMandatoryMessageTest#*
+org.apache.qpid.test.unit.client.connection.ExceptionListenerTest#testExceptionListenerConnectionStopDeadlock
 org.apache.qpid.systest.rest.BrokerRestTest#testSetCloseOnNoRoute
 
 //this test checks explicitly for 0-8 flow control semantics
@@ -68,3 +69,6 @@ org.apache.qpid.client.AsynchMessageList
 
 // QPID-2796 : Java 0-10 client only sends heartbeats in response to heartbeats from the server, not timeout based
 org.apache.qpid.client.HeartbeatTest#testReadOnlyConnectionHeartbeats
+
+// Java 0-10 client does not support re-binding the queue to the same exchange
+org.apache.qpid.server.queue.QueueBindTest#testQueueCanBeReboundOnTopicExchange

Modified: qpid/branches/linearstore/qpid/java/test-profiles/testprofile.defaults
URL: http://svn.apache.org/viewvc/qpid/branches/linearstore/qpid/java/test-profiles/testprofile.defaults?rev=1525101&r1=1525100&r2=1525101&view=diff
==============================================================================
--- qpid/branches/linearstore/qpid/java/test-profiles/testprofile.defaults (original)
+++ qpid/branches/linearstore/qpid/java/test-profiles/testprofile.defaults Fri Sep 20 18:59:30 2013
@@ -17,7 +17,7 @@
 # under the License.
 #
 java.naming.factory.initial=org.apache.qpid.jndi.PropertiesFileInitialContextFactory
-java.naming.provider.url=${test.profiles}/test-provider.properties
+java.naming.provider.url=${test.profiles}${file.separator}test-provider.properties
 
 broker.ready=Listening on TCP
 broker.config=build/etc/config-systests.json
@@ -36,7 +36,7 @@ root.logging.level=warn
 
 # System property log4j.configuration is used by log4j.
 # QpidBrokerTestCase uses log4j.configuration.file to construct a java.io.File, eg for log configuration of spawned brokers.
-log4j.configuration.file=${test.profiles}/log4j-test.xml
+log4j.configuration.file=${test.profiles}${file.separator}log4j-test.xml
 log4j.configuration=file:///${log4j.configuration.file}
 
 log4j.debug=false
@@ -63,6 +63,6 @@ exclude.modules=none
 
 profile.clustered=false
 broker.config-store-type=json
-broker.virtualhosts-config="${QPID_HOME}/etc/virtualhosts-systests.xml"
+broker.virtualhosts-config="${QPID_HOME}${file.separator}etc${file.separator}virtualhosts-systests.xml"
 
 

Propchange: qpid/branches/linearstore/qpid/java/test-profiles/testprofile.defaults
------------------------------------------------------------------------------
  Merged /qpid/trunk/qpid/java/test-profiles/testprofile.defaults:r1501885-1525056

Propchange: qpid/branches/linearstore/qpid/packaging/windows/
------------------------------------------------------------------------------
  Merged /qpid/trunk/qpid/packaging/windows:r1501885-1525056

Modified: qpid/branches/linearstore/qpid/packaging/windows/INSTALL_NOTES.html
URL: http://svn.apache.org/viewvc/qpid/branches/linearstore/qpid/packaging/windows/INSTALL_NOTES.html?rev=1525101&r1=1525100&r2=1525101&view=diff
==============================================================================
--- qpid/branches/linearstore/qpid/packaging/windows/INSTALL_NOTES.html (original)
+++ qpid/branches/linearstore/qpid/packaging/windows/INSTALL_NOTES.html Fri Sep 20 18:59:30 2013
@@ -1,11 +1,11 @@
 <html>
 <head>
-<title>Apache Qpid C++ 0.23 Installation Notes</title>
+<title>Apache Qpid C++ 0.25 Installation Notes</title>
 </head>
 <body>
-<H1>Apache Qpid C++ 0.23 Installation Notes</H1>
+<H1>Apache Qpid C++ 0.25 Installation Notes</H1>
 
-<p>Thank you for installing Apache Qpid version 0.23 for Windows.
+<p>Thank you for installing Apache Qpid version 0.25 for Windows.
 If the requisite features were installed, you can now run a broker,
 use the example programs, and design your own messaging programs while
 reading the Qpid C++ API reference documentation.</p>
@@ -83,7 +83,7 @@ default; therefore, to gain support for 
 must be loaded into the broker. This can be done using the
 <code>--load-module</code> option to load the needed plugins. For example:
 <pre>
-cd "C:\Program Files\Apache\qpidc-0.23"
+cd "C:\Program Files\Apache\qpidc-0.25"
 qpidd.exe --load-module plugins\broker\store.dll --load-module plugins\broker\msclfs_store.dll
 </pre>
 The <code>--load-module</code> option can also take a full path. The option

Modified: qpid/branches/linearstore/qpid/packaging/windows/installer.proj
URL: http://svn.apache.org/viewvc/qpid/branches/linearstore/qpid/packaging/windows/installer.proj?rev=1525101&r1=1525100&r2=1525101&view=diff
==============================================================================
--- qpid/branches/linearstore/qpid/packaging/windows/installer.proj (original)
+++ qpid/branches/linearstore/qpid/packaging/windows/installer.proj Fri Sep 20 18:59:30 2013
@@ -32,7 +32,7 @@
 	<source_root>$(MSBuildProjectDirectory)\..\..</source_root>
 	<staging_dir>$(MSBuildProjectDirectory)\stage</staging_dir>
 	<bits Condition="'$(bits)' == ''">32</bits>
-	<qpid_version>0.23</qpid_version>
+	<qpid_version>0.25</qpid_version>
 	<OutputName>qpidc</OutputName>
 	<OutputType>Package</OutputType>
 	<WixToolPath>C:\Program Files (x86)\Windows Installer XML v3.5\bin</WixToolPath>

Propchange: qpid/branches/linearstore/qpid/packaging/windows/installer.proj
------------------------------------------------------------------------------
  Merged /qpid/trunk/qpid/packaging/windows/installer.proj:r1501885-1525056

Modified: qpid/branches/linearstore/qpid/packaging/windows/qpidc.wxs
URL: http://svn.apache.org/viewvc/qpid/branches/linearstore/qpid/packaging/windows/qpidc.wxs?rev=1525101&r1=1525100&r2=1525101&view=diff
==============================================================================
--- qpid/branches/linearstore/qpid/packaging/windows/qpidc.wxs (original)
+++ qpid/branches/linearstore/qpid/packaging/windows/qpidc.wxs Fri Sep 20 18:59:30 2013
@@ -96,8 +96,7 @@
         <!-- This registry key, values, procedure, and reasoning are
              described at http://support.microsoft.com/kb/817066
              It's necessary for the WCF XA support to work properly. -->
-        <RegistryKey Root="HKLM" Key="SOFTWARE\Microsoft\MSDTC\XADLL"
-                     Action="create">
+        <RegistryKey Root="HKLM" Key="SOFTWARE\Microsoft\MSDTC\XADLL">
           <RegistryValue Type="string"
                          Name="qpidxarm.dll"
                          Value="[QpidBin]qpidxarm.dll" />

Propchange: qpid/branches/linearstore/qpid/python/
------------------------------------------------------------------------------
  Merged /qpid/trunk/qpid/python:r1501885-1525056

Propchange: qpid/branches/linearstore/qpid/python/examples/api/spout
------------------------------------------------------------------------------
    svn:executable = *

Propchange: qpid/branches/linearstore/qpid/python/examples/api/spout
------------------------------------------------------------------------------
    svn:mergeinfo = /qpid/trunk/qpid/python/examples/api/spout:1524673-1525056

Modified: qpid/branches/linearstore/qpid/python/qpid/tests/messaging/__init__.py
URL: http://svn.apache.org/viewvc/qpid/branches/linearstore/qpid/python/qpid/tests/messaging/__init__.py?rev=1525101&r1=1525100&r2=1525101&view=diff
==============================================================================
--- qpid/branches/linearstore/qpid/python/qpid/tests/messaging/__init__.py (original)
+++ qpid/branches/linearstore/qpid/python/qpid/tests/messaging/__init__.py Fri Sep 20 18:59:30 2013
@@ -20,7 +20,7 @@
 import time
 from math import ceil
 from qpid.harness import Skipped
-from qpid.messaging import *
+from qpid.tests.messaging.implementation import *
 from qpid.tests import Test
 
 class Base(Test):
@@ -115,7 +115,7 @@ class Base(Test):
         echo = echo.content
         assert msg == echo, "expected %s, got %s" % (msg, echo)
     else:
-      delta = self.diff(msg, echo, ("x-amqp-0-10.routing-key",))
+      delta = self.diff(msg, echo, ("x-amqp-0-10.routing-key","qpid.subject"))
       mttl, ettl = delta.pop("ttl", (0, 0))
       if redelivered:
         assert echo.redelivered, \
@@ -179,7 +179,26 @@ class Base(Test):
       return "tcp"
 
   def connection_options(self):
-    return {"reconnect": self.reconnect(),
-            "transport": self.transport()}
+    protocol_version = self.config.defines.get("protocol_version")
+    if protocol_version:
+      return {"reconnect": self.reconnect(),
+              "transport": self.transport(),
+              "protocol":protocol_version}
+    else:
+      return {"reconnect": self.reconnect(),
+              "transport": self.transport()}
+
+class VersionTest (Base):
+  def create_connection(self, version="amqp1.0", force=False):
+    opts = self.connection_options()
+    if force or not 'protocol' in opts:
+      opts['protocol'] = version;
+    return Connection.establish(self.broker, **opts)
+
+  def setup_connection(self):
+    return self.create_connection()
+
+  def setup_session(self):
+    return self.conn.session()
 
 import address, endpoints, message

Modified: qpid/branches/linearstore/qpid/python/qpid/tests/messaging/message.py
URL: http://svn.apache.org/viewvc/qpid/branches/linearstore/qpid/python/qpid/tests/messaging/message.py?rev=1525101&r1=1525100&r2=1525101&view=diff
==============================================================================
--- qpid/branches/linearstore/qpid/python/qpid/tests/messaging/message.py (original)
+++ qpid/branches/linearstore/qpid/python/qpid/tests/messaging/message.py Fri Sep 20 18:59:30 2013
@@ -17,7 +17,8 @@
 # under the License.
 #
 
-from qpid.messaging import *
+from qpid.tests.messaging.implementation import *
+from qpid.messaging.address import parse
 from qpid.tests.messaging import Base
 
 class MessageTests(Base):
@@ -110,6 +111,17 @@ class MessageEchoTests(Base):
     msg.reply_to = "reply-address"
     self.check(msg)
 
+  def testApplicationProperties(self):
+    msg = Message()
+    msg.properties["a"] = u"A"
+    msg.properties["b"] = 1
+    msg.properties["c"] = ["x", 2]
+    msg.properties["d"] = "D"
+    #make sure deleting works as expected
+    msg.properties["foo"] = "bar"
+    del msg.properties["foo"]
+    self.check(msg)
+
   def testContentTypeUnknown(self):
     msg = Message(content_type = "this-content-type-does-not-exist")
     self.check(msg)
@@ -126,7 +138,14 @@ class MessageEchoTests(Base):
     msg = Message(reply_to=addr)
     self.snd.send(msg)
     echo = self.rcv.fetch(0)
-    assert echo.reply_to == expected, echo.reply_to
+    #reparse addresses and check individual parts as this avoids
+    #failing due to differenecs in whitespace when running over
+    #swigged client:
+    (actual_name, actual_subject, actual_options) = parse(echo.reply_to)
+    (expected_name, expected_subject, expected_options) = parse(expected)
+    assert actual_name == expected_name, (actual_name, expected_name)
+    assert actual_subject == expected_subject, (actual_subject, expected_subject)
+    assert actual_options == expected_options, (actual_options, expected_options)
     self.ssn.acknowledge(echo)
 
   def testReplyTo(self):

Modified: qpid/branches/linearstore/qpid/python/setup.py
URL: http://svn.apache.org/viewvc/qpid/branches/linearstore/qpid/python/setup.py?rev=1525101&r1=1525100&r2=1525101&view=diff
==============================================================================
--- qpid/branches/linearstore/qpid/python/setup.py (original)
+++ qpid/branches/linearstore/qpid/python/setup.py Fri Sep 20 18:59:30 2013
@@ -298,7 +298,7 @@ class install_lib(_install_lib):
     return outfiles + extra
 
 setup(name="qpid-python",
-      version="0.23",
+      version="0.25",
       author="Apache Qpid",
       author_email="dev@qpid.apache.org",
       packages=["mllib", "qpid", "qpid.messaging", "qpid.tests",

Modified: qpid/branches/linearstore/qpid/tests/setup.py
URL: http://svn.apache.org/viewvc/qpid/branches/linearstore/qpid/tests/setup.py?rev=1525101&r1=1525100&r2=1525101&view=diff
==============================================================================
--- qpid/branches/linearstore/qpid/tests/setup.py (original)
+++ qpid/branches/linearstore/qpid/tests/setup.py Fri Sep 20 18:59:30 2013
@@ -20,7 +20,7 @@
 from distutils.core import setup
 
 setup(name="qpid-tests",
-      version="0.23",
+      version="0.25",
       author="Apache Qpid",
       author_email="dev@qpid.apache.org",
       packages=["qpid_tests", "qpid_tests.broker_0_10", "qpid_tests.broker_0_9",

Modified: qpid/branches/linearstore/qpid/tests/src/py/qpid_tests/broker_0_10/lvq.py
URL: http://svn.apache.org/viewvc/qpid/branches/linearstore/qpid/tests/src/py/qpid_tests/broker_0_10/lvq.py?rev=1525101&r1=1525100&r2=1525101&view=diff
==============================================================================
--- qpid/branches/linearstore/qpid/tests/src/py/qpid_tests/broker_0_10/lvq.py (original)
+++ qpid/branches/linearstore/qpid/tests/src/py/qpid_tests/broker_0_10/lvq.py Fri Sep 20 18:59:30 2013
@@ -17,7 +17,7 @@
 # under the License.
 #
 
-from qpid.messaging import *
+from qpid.tests.messaging.implementation import *
 from qpid.tests.messaging import Base
 import math
 
@@ -61,8 +61,7 @@ class LVQTests (Base):
 
 
 def create_message(key, content):
-    msg = Message(content=content)
-    msg.properties["lvq-key"] = key
+    msg = Message(content=content, properties={"lvq-key":key})
     return msg
 
 def fetch_all(rcv):

Modified: qpid/branches/linearstore/qpid/tests/src/py/qpid_tests/broker_0_10/new_api.py
URL: http://svn.apache.org/viewvc/qpid/branches/linearstore/qpid/tests/src/py/qpid_tests/broker_0_10/new_api.py?rev=1525101&r1=1525100&r2=1525101&view=diff
==============================================================================
--- qpid/branches/linearstore/qpid/tests/src/py/qpid_tests/broker_0_10/new_api.py (original)
+++ qpid/branches/linearstore/qpid/tests/src/py/qpid_tests/broker_0_10/new_api.py Fri Sep 20 18:59:30 2013
@@ -17,9 +17,8 @@
 # under the License.
 #
 
-from qpid.messaging import *
+from qpid.tests.messaging.implementation import *
 from qpid.tests.messaging import Base
-import qmf.console
 from time import sleep
 
 #
@@ -141,7 +140,7 @@ class SequenceNumberTests(Base):
         return self.conn.session()
 
     def setup_sender(self, name="ring-sequence-queue", key="qpid.queue_msg_sequence"):
-        addr = "%s; {create:sender, delete:always, node: {x-declare: {arguments: {'qpid.queue_msg_sequence':'%s', 'qpid.policy_type':'ring', 'qpid.max_count':4}}}}"  % (name, key)
+        addr = "%s; {create:sender, node: {x-declare: {auto-delete: True, arguments: {'qpid.queue_msg_sequence':'%s', 'qpid.policy_type':'ring', 'qpid.max_count':4}}}}"  % (name, key)
         sender = self.ssn.sender(addr)
         return sender
 
@@ -203,3 +202,4 @@ class SequenceNumberTests(Base):
             txt = "Unexpected sequence number. Should be 3. Received (%s)" % seqNo
             self.fail(txt)
         receiver.close()
+

Modified: qpid/branches/linearstore/qpid/tests/src/py/qpid_tests/broker_0_10/priority.py
URL: http://svn.apache.org/viewvc/qpid/branches/linearstore/qpid/tests/src/py/qpid_tests/broker_0_10/priority.py?rev=1525101&r1=1525100&r2=1525101&view=diff
==============================================================================
--- qpid/branches/linearstore/qpid/tests/src/py/qpid_tests/broker_0_10/priority.py (original)
+++ qpid/branches/linearstore/qpid/tests/src/py/qpid_tests/broker_0_10/priority.py Fri Sep 20 18:59:30 2013
@@ -17,7 +17,7 @@
 # under the License.
 #
 
-from qpid.messaging import *
+from qpid.tests.messaging.implementation import *
 from qpid.tests.messaging import Base
 from qpid.compat import set
 import math

Modified: qpid/branches/linearstore/qpid/tests/src/py/qpid_tests/broker_0_10/stats.py
URL: http://svn.apache.org/viewvc/qpid/branches/linearstore/qpid/tests/src/py/qpid_tests/broker_0_10/stats.py?rev=1525101&r1=1525100&r2=1525101&view=diff
==============================================================================
--- qpid/branches/linearstore/qpid/tests/src/py/qpid_tests/broker_0_10/stats.py (original)
+++ qpid/branches/linearstore/qpid/tests/src/py/qpid_tests/broker_0_10/stats.py Fri Sep 20 18:59:30 2013
@@ -17,9 +17,8 @@
 # under the License.
 #
 
-from qpid.messaging import *
+from qpid.tests.messaging.implementation import *
 from qpid.tests.messaging import Base
-import qmf.console
 from time import sleep
 from qpidtoollibs.broker import BrokerAgent
 

Modified: qpid/branches/linearstore/qpid/tests/src/py/qpid_tests/broker_0_10/threshold.py
URL: http://svn.apache.org/viewvc/qpid/branches/linearstore/qpid/tests/src/py/qpid_tests/broker_0_10/threshold.py?rev=1525101&r1=1525100&r2=1525101&view=diff
==============================================================================
--- qpid/branches/linearstore/qpid/tests/src/py/qpid_tests/broker_0_10/threshold.py (original)
+++ qpid/branches/linearstore/qpid/tests/src/py/qpid_tests/broker_0_10/threshold.py Fri Sep 20 18:59:30 2013
@@ -124,11 +124,10 @@ class ThresholdTests (Base):
 
     def test_alert_on_alert_queue(self):
         rcv = self.ssn.receiver("qmf.default.topic/agent.ind.event.org_apache_qpid_broker.queueThresholdCrossedUpward.#; {link:{x-declare:{arguments:{'qpid.alert_count':1}}}}")
-        rcvQMFv1 = self.ssn.receiver("qpid.management/console.event.#; {link:{x-declare:{arguments:{'qpid.alert_count':1}}}}")
         snd = self.ssn.sender("ttq; {create:always, node: {x-declare:{auto_delete:True,exclusive:True,arguments:{'qpid.alert_count':1}}}}")
         snd.send(Message("my-message"))
         queues = []
-        for i in range(3):
+        for i in range(2):
             event = rcv.fetch(timeout=1)
             schema = event.content[0]["_schema_id"]
             assert schema["_class_name"] == "queueThresholdCrossedUpward"

Modified: qpid/branches/linearstore/qpid/tools/setup.py
URL: http://svn.apache.org/viewvc/qpid/branches/linearstore/qpid/tools/setup.py?rev=1525101&r1=1525100&r2=1525101&view=diff
==============================================================================
--- qpid/branches/linearstore/qpid/tools/setup.py (original)
+++ qpid/branches/linearstore/qpid/tools/setup.py Fri Sep 20 18:59:30 2013
@@ -20,14 +20,12 @@
 from distutils.core import setup
 
 setup(name="qpid-tools",
-      version="0.23",
+      version="0.25",
       author="Apache Qpid",
       author_email="dev@qpid.apache.org",
       package_dir={'' : 'src/py'},
       packages=["qpidtoollibs"],
-      scripts=["src/py/qpid-cluster",
-               "src/py/qpid-cluster-store",
-               "src/py/qpid-config",
+      scripts=["src/py/qpid-config",
                "src/py/qpid-ha",
                "src/py/qpid-printevents",
                "src/py/qpid-queue-stats",

Modified: qpid/branches/linearstore/qpid/tools/src/java/README-Java-Broker.txt
URL: http://svn.apache.org/viewvc/qpid/branches/linearstore/qpid/tools/src/java/README-Java-Broker.txt?rev=1525101&r1=1525100&r2=1525101&view=diff
==============================================================================
--- qpid/branches/linearstore/qpid/tools/src/java/README-Java-Broker.txt (original)
+++ qpid/branches/linearstore/qpid/tools/src/java/README-Java-Broker.txt Fri Sep 20 18:59:30 2013
@@ -1,3 +1,23 @@
+/*
+ *
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ *
+ */
 
 The Qpid Java Broker by default uses either JMX or an HTTP Management GUI & REST API, however by building
 a QMF2 Agent as a Java Broker plugin it's possible to provide better synergy between the C++ and Java Brokers

Modified: qpid/branches/linearstore/qpid/tools/src/java/README.txt
URL: http://svn.apache.org/viewvc/qpid/branches/linearstore/qpid/tools/src/java/README.txt?rev=1525101&r1=1525100&r2=1525101&view=diff
==============================================================================
--- qpid/branches/linearstore/qpid/tools/src/java/README.txt (original)
+++ qpid/branches/linearstore/qpid/tools/src/java/README.txt Fri Sep 20 18:59:30 2013
@@ -1,3 +1,23 @@
+/*
+ *
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ *
+ */
 
 This is a Java JMS implementation of the QMF2 API specified at
 https://cwiki.apache.org/qpid/qmfv2-api-proposal.html

Modified: qpid/branches/linearstore/qpid/tools/src/java/bin/qpid-web/authentication/account.properties
URL: http://svn.apache.org/viewvc/qpid/branches/linearstore/qpid/tools/src/java/bin/qpid-web/authentication/account.properties?rev=1525101&r1=1525100&r2=1525101&view=diff
==============================================================================
--- qpid/branches/linearstore/qpid/tools/src/java/bin/qpid-web/authentication/account.properties (original)
+++ qpid/branches/linearstore/qpid/tools/src/java/bin/qpid-web/authentication/account.properties Fri Sep 20 18:59:30 2013
@@ -1,3 +1,23 @@
 #
+#
+# Licensed to the Apache Software Foundation (ASF) under one
+# or more contributor license agreements.  See the NOTICE file
+# distributed with this work for additional information
+# regarding copyright ownership.  The ASF licenses this file
+# to you under the Apache License, Version 2.0 (the
+# "License"); you may not use this file except in compliance
+# with the License.  You may obtain a copy of the License at
+#
+#   http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing,
+# software distributed under the License is distributed on an
+# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+# KIND, either express or implied.  See the License for the
+# specific language governing permissions and limitations
+# under the License.
+#
+#
+
 guest=guest
 admin=admin

Modified: qpid/branches/linearstore/qpid/tools/src/java/bin/qpid-web/web/index.html
URL: http://svn.apache.org/viewvc/qpid/branches/linearstore/qpid/tools/src/java/bin/qpid-web/web/index.html?rev=1525101&r1=1525100&r2=1525101&view=diff
==============================================================================
--- qpid/branches/linearstore/qpid/tools/src/java/bin/qpid-web/web/index.html (original)
+++ qpid/branches/linearstore/qpid/tools/src/java/bin/qpid-web/web/index.html Fri Sep 20 18:59:30 2013
@@ -1,4 +1,22 @@
 <!DOCTYPE html>
+<!--
+  Licensed to the Apache Software Foundation (ASF) under one
+  or more contributor license agreements.  See the NOTICE file
+  distributed with this work for additional information
+  regarding copyright ownership.  The ASF licenses this file
+  to you under the Apache License, Version 2.0 (the
+  "License"); you may not use this file except in compliance
+  with the License.  You may obtain a copy of the License at
+  
+    http://www.apache.org/licenses/LICENSE-2.0
+  
+  Unless required by applicable law or agreed to in writing,
+  software distributed under the License is distributed on an
+  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+  KIND, either express or implied.  See the License for the
+  specific language governing permissions and limitations
+  under the License.
+-->
 
 <!--
 This page provides a "welcome" page for the Qpid REST Service it immediately redirects to ui/qmf.html

Modified: qpid/branches/linearstore/qpid/tools/src/java/bin/qpid-web/web/itablet/css/itablet-ie6.css
URL: http://svn.apache.org/viewvc/qpid/branches/linearstore/qpid/tools/src/java/bin/qpid-web/web/itablet/css/itablet-ie6.css?rev=1525101&r1=1525100&r2=1525101&view=diff
==============================================================================
--- qpid/branches/linearstore/qpid/tools/src/java/bin/qpid-web/web/itablet/css/itablet-ie6.css (original)
+++ qpid/branches/linearstore/qpid/tools/src/java/bin/qpid-web/web/itablet/css/itablet-ie6.css Fri Sep 20 18:59:30 2013
@@ -1,3 +1,24 @@
+/*
+ *
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ *
+ */
+
 /**
  * Stylesheet to try and make things look not *too* bad in IE6 and below. Supporting IE6 really is a nightmare :-(
  */

Modified: qpid/branches/linearstore/qpid/tools/src/java/bin/qpid-web/web/itablet/css/itablet-ie7.css
URL: http://svn.apache.org/viewvc/qpid/branches/linearstore/qpid/tools/src/java/bin/qpid-web/web/itablet/css/itablet-ie7.css?rev=1525101&r1=1525100&r2=1525101&view=diff
==============================================================================
--- qpid/branches/linearstore/qpid/tools/src/java/bin/qpid-web/web/itablet/css/itablet-ie7.css (original)
+++ qpid/branches/linearstore/qpid/tools/src/java/bin/qpid-web/web/itablet/css/itablet-ie7.css Fri Sep 20 18:59:30 2013
@@ -1,3 +1,24 @@
+/*
+ *
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ *
+ */
+
 /**
  * Stylesheet to try and make things look not *too* bad in IE7.
  */

Modified: qpid/branches/linearstore/qpid/tools/src/java/bin/qpid-web/web/itablet/css/itablet-ie8.css
URL: http://svn.apache.org/viewvc/qpid/branches/linearstore/qpid/tools/src/java/bin/qpid-web/web/itablet/css/itablet-ie8.css?rev=1525101&r1=1525100&r2=1525101&view=diff
==============================================================================
--- qpid/branches/linearstore/qpid/tools/src/java/bin/qpid-web/web/itablet/css/itablet-ie8.css (original)
+++ qpid/branches/linearstore/qpid/tools/src/java/bin/qpid-web/web/itablet/css/itablet-ie8.css Fri Sep 20 18:59:30 2013
@@ -1,3 +1,24 @@
+/*
+ *
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ *
+ */
+
 /**
  * Stylesheet to try and make things look not *too* bad in IE8 and below
  */

Modified: qpid/branches/linearstore/qpid/tools/src/java/bin/qpid-web/web/itablet/css/itablet-ie9.css
URL: http://svn.apache.org/viewvc/qpid/branches/linearstore/qpid/tools/src/java/bin/qpid-web/web/itablet/css/itablet-ie9.css?rev=1525101&r1=1525100&r2=1525101&view=diff
==============================================================================
--- qpid/branches/linearstore/qpid/tools/src/java/bin/qpid-web/web/itablet/css/itablet-ie9.css (original)
+++ qpid/branches/linearstore/qpid/tools/src/java/bin/qpid-web/web/itablet/css/itablet-ie9.css Fri Sep 20 18:59:30 2013
@@ -1,3 +1,24 @@
+/*
+ *
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ *
+ */
+
 /**
  * Stylesheet to sort out IE9 specific quirks.......
  */

Modified: qpid/branches/linearstore/qpid/tools/src/java/bin/qpid-web/web/itablet/css/itablet.css
URL: http://svn.apache.org/viewvc/qpid/branches/linearstore/qpid/tools/src/java/bin/qpid-web/web/itablet/css/itablet.css?rev=1525101&r1=1525100&r2=1525101&view=diff
==============================================================================
--- qpid/branches/linearstore/qpid/tools/src/java/bin/qpid-web/web/itablet/css/itablet.css (original)
+++ qpid/branches/linearstore/qpid/tools/src/java/bin/qpid-web/web/itablet/css/itablet.css Fri Sep 20 18:59:30 2013
@@ -1,3 +1,23 @@
+/*
+ *
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ *
+ */
 
 body
 {

Modified: qpid/branches/linearstore/qpid/tools/src/java/bin/qpid-web/web/itablet/scripts/LICENCE
URL: http://svn.apache.org/viewvc/qpid/branches/linearstore/qpid/tools/src/java/bin/qpid-web/web/itablet/scripts/LICENCE?rev=1525101&r1=1525100&r2=1525101&view=diff
==============================================================================
--- qpid/branches/linearstore/qpid/tools/src/java/bin/qpid-web/web/itablet/scripts/LICENCE (original)
+++ qpid/branches/linearstore/qpid/tools/src/java/bin/qpid-web/web/itablet/scripts/LICENCE Fri Sep 20 18:59:30 2013
@@ -1,27 +1,3 @@
-/*
- * itablet.js
- *
- * Copyright (c) 2013, Fraser Adams
- *
- * Licensed to the Apache Software Foundation (ASF) under one
- * or more contributor license agreements.  See the NOTICE file
- * distributed with this work for additional information
- * regarding copyright ownership.  The ASF licenses this file
- * to you under the Apache License, Version 2.0 (the
- * "License"); you may not use this file except in compliance
- * with the License.  You may obtain a copy of the License at
- *
- *   http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing,
- * software distributed under the License is distributed on an
- * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
- * KIND, either express or implied.  See the License for the
- * specific language governing permissions and limitations
- * under the License.
- *
- */
-
 
 /*
  * jQuery JavaScript Library v1.7.1

Modified: qpid/branches/linearstore/qpid/tools/src/java/bin/qpid-web/web/itablet/scripts/itablet.js
URL: http://svn.apache.org/viewvc/qpid/branches/linearstore/qpid/tools/src/java/bin/qpid-web/web/itablet/scripts/itablet.js?rev=1525101&r1=1525100&r2=1525101&view=diff
==============================================================================
--- qpid/branches/linearstore/qpid/tools/src/java/bin/qpid-web/web/itablet/scripts/itablet.js (original)
+++ qpid/branches/linearstore/qpid/tools/src/java/bin/qpid-web/web/itablet/scripts/itablet.js Fri Sep 20 18:59:30 2013
@@ -1,5 +1,25 @@
+/*
+ *
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ *
+ */
+
 /**
- * http://www.apache.org/licenses/LICENSE-2.0
  *
  * This library implements a general user interface look and feel similar to a "well know tablet PC" :-)
  * It provides animated page transition eye-candy but is, in essence, really just a fancy tabbed window.

Modified: qpid/branches/linearstore/qpid/tools/src/java/bin/qpid-web/web/qmf-ui/css/index.css
URL: http://svn.apache.org/viewvc/qpid/branches/linearstore/qpid/tools/src/java/bin/qpid-web/web/qmf-ui/css/index.css?rev=1525101&r1=1525100&r2=1525101&view=diff
==============================================================================
--- qpid/branches/linearstore/qpid/tools/src/java/bin/qpid-web/web/qmf-ui/css/index.css (original)
+++ qpid/branches/linearstore/qpid/tools/src/java/bin/qpid-web/web/qmf-ui/css/index.css Fri Sep 20 18:59:30 2013
@@ -1,3 +1,24 @@
+/*
+ *
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ *
+ */
+
 html
 {
     background: black;

Modified: qpid/branches/linearstore/qpid/tools/src/java/bin/qpid-web/web/qmf-ui/css/qmf.css
URL: http://svn.apache.org/viewvc/qpid/branches/linearstore/qpid/tools/src/java/bin/qpid-web/web/qmf-ui/css/qmf.css?rev=1525101&r1=1525100&r2=1525101&view=diff
==============================================================================
--- qpid/branches/linearstore/qpid/tools/src/java/bin/qpid-web/web/qmf-ui/css/qmf.css (original)
+++ qpid/branches/linearstore/qpid/tools/src/java/bin/qpid-web/web/qmf-ui/css/qmf.css Fri Sep 20 18:59:30 2013
@@ -1,3 +1,23 @@
+/*
+ *
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ *
+ */
 
 a.settings
 {

Modified: qpid/branches/linearstore/qpid/tools/src/java/bin/qpid-web/web/qmf-ui/scripts/LICENCE
URL: http://svn.apache.org/viewvc/qpid/branches/linearstore/qpid/tools/src/java/bin/qpid-web/web/qmf-ui/scripts/LICENCE?rev=1525101&r1=1525100&r2=1525101&view=diff
==============================================================================
--- qpid/branches/linearstore/qpid/tools/src/java/bin/qpid-web/web/qmf-ui/scripts/LICENCE (original)
+++ qpid/branches/linearstore/qpid/tools/src/java/bin/qpid-web/web/qmf-ui/scripts/LICENCE Fri Sep 20 18:59:30 2013
@@ -1,27 +1,3 @@
-/*
- * qmf-ui.js
- *
- * Copyright (c) 2013, Fraser Adams
- *
- * Licensed to the Apache Software Foundation (ASF) under one
- * or more contributor license agreements.  See the NOTICE file
- * distributed with this work for additional information
- * regarding copyright ownership.  The ASF licenses this file
- * to you under the Apache License, Version 2.0 (the
- * "License"); you may not use this file except in compliance
- * with the License.  You may obtain a copy of the License at
- *
- *   http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing,
- * software distributed under the License is distributed on an
- * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
- * KIND, either express or implied.  See the License for the
- * specific language governing permissions and limitations
- * under the License.
- *
- */
-
 
 /*
  * excanvas.js

Modified: qpid/branches/linearstore/qpid/tools/src/java/bin/qpid-web/web/qmf-ui/scripts/qmf-ui.js
URL: http://svn.apache.org/viewvc/qpid/branches/linearstore/qpid/tools/src/java/bin/qpid-web/web/qmf-ui/scripts/qmf-ui.js?rev=1525101&r1=1525100&r2=1525101&view=diff
==============================================================================
--- qpid/branches/linearstore/qpid/tools/src/java/bin/qpid-web/web/qmf-ui/scripts/qmf-ui.js (original)
+++ qpid/branches/linearstore/qpid/tools/src/java/bin/qpid-web/web/qmf-ui/scripts/qmf-ui.js Fri Sep 20 18:59:30 2013
@@ -1,5 +1,25 @@
+/*
+ *
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ *
+ */
+
 /**
- * http://www.apache.org/licenses/LICENSE-2.0
  *
  * This program implements the QMF Console User Interface logic for qmf.html
  *

Modified: qpid/branches/linearstore/qpid/tools/src/java/bin/qpid-web/web/ui/config.js
URL: http://svn.apache.org/viewvc/qpid/branches/linearstore/qpid/tools/src/java/bin/qpid-web/web/ui/config.js?rev=1525101&r1=1525100&r2=1525101&view=diff
==============================================================================
--- qpid/branches/linearstore/qpid/tools/src/java/bin/qpid-web/web/ui/config.js (original)
+++ qpid/branches/linearstore/qpid/tools/src/java/bin/qpid-web/web/ui/config.js Fri Sep 20 18:59:30 2013
@@ -1,9 +1,31 @@
+/*
+ *
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ *
+ */
+
 /**
  * This file allows the initial set of Console Connections to be configured and delivered to the client.
  * The format is as a JSON array of JSON objects containing a url property and optional name, connectionOptions and
  * disableEvents properties. The connectionOptions property has a value that is itself a JSON object containing
  * the connectionOptions supported by the qpid::messaging API.
  */
+
 /*
 // Example Console Connection Configuration.
 qmfui.Console.consoleConnections = [

Modified: qpid/branches/linearstore/qpid/tools/src/java/bin/qpid-web/web/ui/qmf.html
URL: http://svn.apache.org/viewvc/qpid/branches/linearstore/qpid/tools/src/java/bin/qpid-web/web/ui/qmf.html?rev=1525101&r1=1525100&r2=1525101&view=diff
==============================================================================
--- qpid/branches/linearstore/qpid/tools/src/java/bin/qpid-web/web/ui/qmf.html (original)
+++ qpid/branches/linearstore/qpid/tools/src/java/bin/qpid-web/web/ui/qmf.html Fri Sep 20 18:59:30 2013
@@ -1,4 +1,24 @@
 <!DOCTYPE html>
+
+<!--
+  Licensed to the Apache Software Foundation (ASF) under one
+  or more contributor license agreements.  See the NOTICE file
+  distributed with this work for additional information
+  regarding copyright ownership.  The ASF licenses this file
+  to you under the Apache License, Version 2.0 (the
+  "License"); you may not use this file except in compliance
+  with the License.  You may obtain a copy of the License at
+  
+    http://www.apache.org/licenses/LICENSE-2.0
+  
+  Unless required by applicable law or agreed to in writing,
+  software distributed under the License is distributed on an
+  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+  KIND, either express or implied.  See the License for the
+  specific language governing permissions and limitations
+  under the License.
+-->
+
 <html>
 <head>
     <title>QMF Console</title>

Modified: qpid/branches/linearstore/qpid/tools/src/java/src/qpid-broker-plugins-management-qmf2/java/org/apache/qpid/server/qmf2/QmfManagementFactory.java
URL: http://svn.apache.org/viewvc/qpid/branches/linearstore/qpid/tools/src/java/src/qpid-broker-plugins-management-qmf2/java/org/apache/qpid/server/qmf2/QmfManagementFactory.java?rev=1525101&r1=1525100&r2=1525101&view=diff
==============================================================================
--- qpid/branches/linearstore/qpid/tools/src/java/src/qpid-broker-plugins-management-qmf2/java/org/apache/qpid/server/qmf2/QmfManagementFactory.java (original)
+++ qpid/branches/linearstore/qpid/tools/src/java/src/qpid-broker-plugins-management-qmf2/java/org/apache/qpid/server/qmf2/QmfManagementFactory.java Fri Sep 20 18:59:30 2013
@@ -76,4 +76,10 @@ public class QmfManagementFactory implem
             return null;
         }
     }
+
+    @Override
+    public String getType()
+    {
+        return "QMF2 Management";
+    }
 }

Modified: qpid/branches/linearstore/qpid/tools/src/java/src/restapi/java/org/apache/qpid/restapi/servlet/TODO
URL: http://svn.apache.org/viewvc/qpid/branches/linearstore/qpid/tools/src/java/src/restapi/java/org/apache/qpid/restapi/servlet/TODO?rev=1525101&r1=1525100&r2=1525101&view=diff
==============================================================================
--- qpid/branches/linearstore/qpid/tools/src/java/src/restapi/java/org/apache/qpid/restapi/servlet/TODO (original)
+++ qpid/branches/linearstore/qpid/tools/src/java/src/restapi/java/org/apache/qpid/restapi/servlet/TODO Fri Sep 20 18:59:30 2013
@@ -1,3 +1,24 @@
+/*
+ *
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ *
+ */
+
 The org.apache.qpid.restapi.HttpTransaction and org.apache.qpid.restapi.Server interfaces are intended to
 provide abstractions to the underlying HTTP Server technology and thus should make it fairly easy to do
 a Servlet based implementation without having to rewrite the core REST API code. A Servlet implementation

Modified: qpid/branches/linearstore/qpid/tools/src/py/.gitignore
URL: http://svn.apache.org/viewvc/qpid/branches/linearstore/qpid/tools/src/py/.gitignore?rev=1525101&r1=1525100&r2=1525101&view=diff
==============================================================================
--- qpid/branches/linearstore/qpid/tools/src/py/.gitignore (original)
+++ qpid/branches/linearstore/qpid/tools/src/py/.gitignore Fri Sep 20 18:59:30 2013
@@ -17,7 +17,6 @@
 # to you under the Apache License, Version 2.0 (the
 # under the License.
 # with the License.  You may obtain a copy of the License at
-/qpid-clusterc
 /qpid-configc
 /qpid-hac
 /qpid-routec

Modified: qpid/branches/linearstore/qpid/tools/src/py/qpid-config
URL: http://svn.apache.org/viewvc/qpid/branches/linearstore/qpid/tools/src/py/qpid-config?rev=1525101&r1=1525100&r2=1525101&view=diff
==============================================================================
--- qpid/branches/linearstore/qpid/tools/src/py/qpid-config (original)
+++ qpid/branches/linearstore/qpid/tools/src/py/qpid-config Fri Sep 20 18:59:30 2013
@@ -66,9 +66,7 @@ Queue Limit Actions:
 
     none (default) - Use broker's default policy
     reject         - Reject enqueued messages
-    flow-to-disk   - Page messages to disk
     ring           - Replace oldest unacquired message with new
-    ring-strict    - Replace oldest message, reject if oldest is acquired
 
 Replication levels:
 
@@ -198,7 +196,7 @@ def OptionsAndArguments(argv):
     group3.add_option("--file-size", action="store", type="int", metavar="<n>", help="File size in pages (64KiB/page)")
     group3.add_option("--max-queue-size", action="store", type="int", metavar="<n>", help="Maximum in-memory queue size as bytes")
     group3.add_option("--max-queue-count", action="store", type="int", metavar="<n>", help="Maximum in-memory queue size as a number of messages")
-    group3.add_option("--limit-policy", action="store", choices=["none", "reject", "flow-to-disk", "ring", "ring-strict"], metavar="<policy>", help="Action to take when queue limit is reached")
+    group3.add_option("--limit-policy", action="store", choices=["none", "reject", "ring", "ring-strict"], metavar="<policy>", help="Action to take when queue limit is reached")
     group3.add_option("--lvq-key", action="store", metavar="<key>", help="Last Value Queue key")
     group3.add_option("--generate-queue-events", action="store", type="int", metavar="<n>", help="If set to 1, every enqueue will generate an event that can be processed by registered listeners (e.g. for replication). If set to 2, events will be generated for enqueues and dequeues.")
     group3.add_option("--flow-stop-size", action="store", type="int", metavar="<n>",
@@ -597,12 +595,8 @@ class BrokerManager:
                 pass
             elif config._limitPolicy == "reject":
                 declArgs[POLICY_TYPE] = "reject"
-            elif config._limitPolicy == "flow-to-disk":
-                declArgs[POLICY_TYPE] = "flow_to_disk"
             elif config._limitPolicy == "ring":
                 declArgs[POLICY_TYPE] = "ring"
-            elif config._limitPolicy == "ring-strict":
-                declArgs[POLICY_TYPE] = "ring_strict"
 
         if config._clusterDurable:
             declArgs[CLUSTER_DURABLE] = 1



---------------------------------------------------------------------
To unsubscribe, e-mail: commits-unsubscribe@qpid.apache.org
For additional commands, e-mail: commits-help@qpid.apache.org
--- qpid/branches/linearstore/qpid/java/systests/src/main/java/org/apache/qpid/systest/management/jmx/QueueManagementTest.java (original)
+++ qpid/branches/linearstore/qpid/java/systests/src/main/java/org/apache/qpid/systest/management/jmx/QueueManagementTest.java Fri Sep 20 18:59:30 2013
@@ -28,6 +28,7 @@ import org.apache.qpid.management.common
 import org.apache.qpid.management.common.mbeans.ManagedQueue;
 import org.apache.qpid.server.queue.AMQQueueFactory;
 import org.apache.qpid.server.queue.NotificationCheckTest;
+import org.apache.qpid.server.queue.QueueArgumentsConverter;
 import org.apache.qpid.server.queue.SimpleAMQQueue;
 import org.apache.qpid.server.queue.SimpleAMQQueueTest;
 import org.apache.qpid.test.client.destination.AddressBasedDestinationTest;
@@ -168,7 +169,7 @@ public class QueueManagementTest extends
     public void testNewQueueWithDescription() throws Exception
     {
         String queueName = getTestQueueName();
-        Map<String, Object> arguments = Collections.singletonMap(AMQQueueFactory.X_QPID_DESCRIPTION, (Object)TEST_QUEUE_DESCRIPTION);
+        Map<String, Object> arguments = Collections.singletonMap(QueueArgumentsConverter.X_QPID_DESCRIPTION, (Object)TEST_QUEUE_DESCRIPTION);
         ((AMQSession<?, ?>)_session).createQueue(AMQShortString.valueOf(queueName), false, true, false, arguments);
 
         final ManagedQueue managedQueue = _jmxUtils.getManagedQueue(queueName);
@@ -181,7 +182,7 @@ public class QueueManagementTest extends
     public void testQueueDescriptionSurvivesRestart() throws Exception
     {
         String queueName = getTestQueueName();
-        Map<String, Object> arguments = Collections.singletonMap(AMQQueueFactory.X_QPID_DESCRIPTION, (Object)TEST_QUEUE_DESCRIPTION);
+        Map<String, Object> arguments = Collections.singletonMap(QueueArgumentsConverter.X_QPID_DESCRIPTION, (Object)TEST_QUEUE_DESCRIPTION);
 
         ((AMQSession<?, ?>)_session).createQueue(AMQShortString.valueOf(queueName), false, true, false, arguments);
 
@@ -195,7 +196,7 @@ public class QueueManagementTest extends
     }
 
     /**
      * Tests queue creation with {@link AMQQueueFactory#X_QPID_MAXIMUM_DELIVERY_COUNT} argument.  Also tests
      * that the attribute is exposed correctly through {@link ManagedQueue#getMaximumDeliveryCount()}.
      */
     public void testCreateQueueWithMaximumDeliveryCountSet() throws Exception
@@ -204,7 +205,7 @@ public class QueueManagementTest extends
         final ManagedBroker managedBroker = _jmxUtils.getManagedBroker(VIRTUAL_HOST);
 
         final Integer deliveryCount = 1;
-        final Map<String, Object> arguments = Collections.singletonMap(AMQQueueFactory.X_QPID_MAXIMUM_DELIVERY_COUNT, (Object)deliveryCount);
+        final Map<String, Object> arguments = Collections.singletonMap(QueueArgumentsConverter.X_QPID_MAXIMUM_DELIVERY_COUNT, (Object)deliveryCount);
         managedBroker.createNewQueue(queueName, null, true, arguments);
 
         // Ensure the queue exists
@@ -225,10 +226,10 @@ public class QueueManagementTest extends
         final Long maximumQueueDepth = 300l;
         final Long maximumMessageAge = 400l;
         final Map<String, Object> arguments = new HashMap<String, Object>();
-        arguments.put(AMQQueueFactory.X_QPID_MAXIMUM_MESSAGE_COUNT, maximumMessageCount);
-        arguments.put(AMQQueueFactory.X_QPID_MAXIMUM_MESSAGE_SIZE, maximumMessageSize);
-        arguments.put(AMQQueueFactory.X_QPID_MAXIMUM_QUEUE_DEPTH, maximumQueueDepth);
-        arguments.put(AMQQueueFactory.X_QPID_MAXIMUM_MESSAGE_AGE, maximumMessageAge);
+        arguments.put(QueueArgumentsConverter.X_QPID_MAXIMUM_MESSAGE_COUNT, maximumMessageCount);
+        arguments.put(QueueArgumentsConverter.X_QPID_MAXIMUM_MESSAGE_SIZE, maximumMessageSize);
+        arguments.put(QueueArgumentsConverter.X_QPID_MAXIMUM_QUEUE_DEPTH, maximumQueueDepth);
+        arguments.put(QueueArgumentsConverter.X_QPID_MAXIMUM_MESSAGE_AGE, maximumMessageAge);
 
         managedBroker.createNewQueue(queueName, null, true, arguments);
 
@@ -642,7 +643,7 @@ public class QueueManagementTest extends
         final ManagedBroker managedBroker = _jmxUtils.getManagedBroker(VIRTUAL_HOST);
 
         final Object messageGroupKey = "test";
-        final Map<String, Object> arguments = Collections.singletonMap(SimpleAMQQueue.QPID_GROUP_HEADER_KEY, messageGroupKey);
+        final Map<String, Object> arguments = Collections.singletonMap(QueueArgumentsConverter.QPID_GROUP_HEADER_KEY, messageGroupKey);
         managedBroker.createNewQueue(queueName, null, true, arguments);
 
         final ManagedQueue managedQueue = _jmxUtils.getManagedQueue(queueName);
@@ -659,8 +660,8 @@ public class QueueManagementTest extends
 
         final Object messageGroupKey = "test";
         final Map<String, Object> arguments = new HashMap<String, Object>(2);
-        arguments.put(SimpleAMQQueue.QPID_GROUP_HEADER_KEY, messageGroupKey);
-        arguments.put(SimpleAMQQueue.QPID_SHARED_MSG_GROUP, SimpleAMQQueue.SHARED_MSG_GROUP_ARG_VALUE);
+        arguments.put(QueueArgumentsConverter.QPID_GROUP_HEADER_KEY, messageGroupKey);
+        arguments.put(QueueArgumentsConverter.QPID_SHARED_MSG_GROUP, SimpleAMQQueue.SHARED_MSG_GROUP_ARG_VALUE);
         managedBroker.createNewQueue(queueName, null, true, arguments);
 
         final ManagedQueue managedQueue = _jmxUtils.getManagedQueue(queueName);
@@ -195,7 +196,7 @@ public class QueueManagementTest extends
 
     /**
-     * Tests queue creation with {@link AMQQueueFactory#X_QPID_MAXIMUM_DELIVERY_COUNT} argument.  Also tests
+     * Tests queue creation with {@link QueueArgumentsConverter#X_QPID_MAXIMUM_DELIVERY_COUNT} argument.  Also tests
      * that the attribute is exposed correctly through {@link ManagedQueue#getMaximumDeliveryCount()}.
      */

Modified: qpid/branches/linearstore/qpid/java/systests/src/main/java/org/apache/qpid/systest/rest/Asserts.java
URL: http://svn.apache.org/viewvc/qpid/branches/linearstore/qpid/java/systests/src/main/java/org/apache/qpid/systest/rest/Asserts.java?rev=1525101&r1=1525100&r2=1525101&view=diff
==============================================================================